

class MapRegistery:

	METADATA = {

		'map_1' : {
			'map_name' : 'map_1',
			'dimensions' : (700, 700),
			'road_rgb' : (111, 112, 116),
			'init' : {
				'position' : (490, 520),
				'orientation' : 17
				},
			'schema' : [(490, 520), (480, 490), (470, 465), (460, 440), (460, 325), (470, 300), (500, 270), (530, 260), (570, 207), (623, 130), (600, 85), (540, 80), (486, 155), (450, 180), (414, 140), (390, 80), (125, 80), (85, 108), (78, 156), (100, 200), (130, 210), (355, 230), (378, 255), (362, 290), (215, 344), (190, 375), (212, 423), (303, 535), (392, 617), (470, 630), (499, 594), (490, 540), (490, 520)]
		},

		'map_2' : {
			'map_name' : 'map_2',
			'dimensions' : (700, 700),
			'road_rgb' : (110, 111, 115),
			'init' : {
				'position' : (500, 500),
				'orientation' : 0
				},
			'schema' :[(480, 490), (470, 465), (460, 440)]
		},

		'map_3' : {
			'map_name' : 'map_3',
			'dimensions' : (700, 700),
			'road_rgb' : (110, 111, 115),
			'init' : {
				'position' : (500, 500),
				'orientation' : 0
				},
			'schema' :[(480, 490), (470, 465), (460, 440)]
		}

	}